@@ -43,9 +43,13 @@ if TYPE_CHECKING:
         ChatCompletionUserMessageParam,
     )
     from openai.types.vector_stores import VectorStoreFile, VectorStoreFileBatch, VectorStoreFileDeleted
-from airflow.hooks.base import BaseHook
 from airflow.providers.openai.exceptions import OpenAIBatchJobException, OpenAIBatchTimeout
 
+try:
+    from airflow.sdk import BaseHook
+except ImportError:
+    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+
 
 class BatchStatus(str, Enum):
     """Enum for the status of a batch."""
@@ -469,9 +473,9 @@ class OpenAIHook(BaseHook):
                 return
             if batch.status == BatchStatus.FAILED:
                 raise OpenAIBatchJobException(f"Batch failed - \n{batch_id}")
-            elif batch.status in (BatchStatus.CANCELLED, BatchStatus.CANCELLING):
+            if batch.status in (BatchStatus.CANCELLED, BatchStatus.CANCELLING):
                 raise OpenAIBatchJobException(f"Batch failed - batch was cancelled:\n{batch_id}")
-            elif batch.status == BatchStatus.EXPIRED:
+            if batch.status == BatchStatus.EXPIRED:
                 raise OpenAIBatchJobException(
                     f"Batch failed - batch couldn't be completed within the hour time window :\n{batch_id}"
                 )
